====================================
Docstrings for basic field functions
====================================

Field operation functions
=========================

These functions implement some basic operations pertaining to fields
in general.

curl
----

.. autofunction:: sympy.physics.vector.fieldfunctions.curl


divergence
----------

.. autofunction:: sympy.physics.vector.fieldfunctions.divergence


gradient
--------

.. autofunction:: sympy.physics.vector.fieldfunctions.gradient


scalar_potential
----------------

.. autofunction:: sympy.physics.vector.fieldfunctions.scalar_potential


scalar_potential_difference
---------------------------

.. autofunction:: sympy.physics.vector.fieldfunctions.scalar_potential_difference


Checking the type of vector field
=================================

is_conservative
---------------

.. autofunction:: sympy.physics.vector.fieldfunctions.is_conservative


is_solenoidal
-------------

.. autofunction:: sympy.physics.vector.fieldfunctions.is_solenoidal
